<template>
<div class="w-100">
  <div class="product_details_page">
    <div class="__left">
      <div class="_section_top">
        <div class="section_left">
              <div v-swiper:mySwiper="swiperOption" class="gallery-top" ref="swiperTop">
                <div class="swiper-wrapper" v-if="product.main_images" >
                  <!-- product.cover.bySize.home_default.url -->
                  <div class="swiper-slide"
                    v-for="(img, i) in product.main_images"
                    :key="i"
                  >
                    <Lazy
                      :src="img"
                    ></Lazy>
                  </div>
                </div>
                <div class="swiper-pagination swiper-pagination-bullets"></div>
              </div>
              <div
                  v-swiper:mySwiperThumbs="swiperOptionThumbs"
                  ref="swiperThumbs"
                  class="gallery-thumbs"
              >
                <div class="swiper-wrapper" v-if="product.main_images">
                  <!-- product.cover.bySize.home_default.url -->
                  <div class="swiper-slide" v-for="(img, i) in product.main_images" :key="i">
                    <a href="#" class="product-cover">
                      <Lazy
                        :src="img"
                      >
                      </Lazy>
                    </a>
                  </div>
                </div>
                <div class="swiper-pagination swiper-pagination-bullets"></div>
              </div>
          </div>

          <div class="section_center">
            <div class="product_title">
              <h1 class="title raleway margin-0">{{ product.name }}</h1>
            </div>

            <div class="details">
              <div class="flex align-center">
                  <div class="__price_tag pa-0" v-text="product.price"></div>
              </div>

              <div class="__product_detail_desc" v-html="product.description_short"></div>
            </div>
          </div>

          <div class="section_right">
            <div class="cart_side">
              <div class="_attributes" :key="ind" v-for="(comb, ind) in product.all_combinations.values" v-if="product.all_combinations && product.product_type != 'Stem'">
                <div :class="'length_title ' + ind + '_hide'">{{ ind }}</div>
                <div :class="'row flex wrap ' + ind + '_hide'">
                    <div class="_abs" v-for="(cc, i) in comb" :key="i">
                      <div>
                        <div @click="changeAttribute(cc)" :class="'length_box' +  getSelected(cc)"> {{ cc.value }} </div>
                      </div>
                    </div>
                  </div>
              </div>
              <div class="length_title raleway" v-if="product.product_type == 'Box'"> PALLETS</div>
              <div class="length_title raleway" v-else-if="product.product_type == 'Stem'">STEMS (Average 1,330 Pounds)</div>
              <div class="length_title raleway" v-else-if="product.product_type == 'Bale'">Bundles</div>
              <div class="row bundle_boxes">
                    <v-select
                        :items="product.quantities"
                        v-model="qty"
                        outline
                        full-width
                        label="Quantity"
                    ></v-select>

                <div class="_error_msg" id="_error_msg">
                  The minimum purchase order quantity for the product is 2
                  <i class="material-icons" id="close_error">
                    close
                  </i>
                </div>
              </div>
              <div v-if="comb_not_found" class="mt-3 mb-2">
                <v-alert :value="true" type="error">
                  This combination does not exist!
                </v-alert>
              </div>
              <div class="mt-3 mb-2" v-else>
                <input type="hidden" v-if="product" :value="product.id_product_attribute" name="id_product_attribute">
                <input type="hidden" :value="product.id_product" name="id_product">
                <v-btn
                  color="secondary"
                  dark
                  @click="addToCart"
                  block
                  :loading="addProcess"
                  class="mb-2"
                  large
                  ripple >
                    <i class="material-icons">
                      shopping_cart
                    </i>
                  add to cart
                </v-btn>
                <v-divider class="mb-2" v-if="this.product.product_type == 'Bale'"></v-divider>
                <v-btn
                  color="success"
                  large
                  block
                  class="ofpb"
                  :loading="maxBundleLoad"
                  v-if="this.product.product_type == 'Bale'"
                  dark
                  ripple
                  @click="maxBundleQtyToCart"
                >Order 1 Full Pallet ({{ maxQty }}) bundles</v-btn>
              </div>
            </div>
          </div>
      </div>
      <div class="_section_bottom container" v-if="product.description">
        <div class="_description">
          <div v-html="product.description"></div>
          <div v-if="product && product.all_combinations && product.all_combinations.combination_urls">

            <p class="dh">Other Combinations</p>
            <v-list>
              <v-list-tile
              v-for="(url, index) in product.all_combinations.combination_urls"
              :key="index"
              :href="url"
              target="_blank"
              >
              <v-list-tile-title>{{ index }}</v-list-tile-title>
              </v-list-tile>
            </v-list>

          </div>

        </div>
      </div>
    </div>
  </div>
</div>
</template>

<script>
import axios from 'axios';
import 'swiper/dist/css/swiper.css';

export default {
  scrollToTop: true,
 mounted () {
    this.$nextTick(() => {
      const swiperTop = this.mySwiper;
      const swiperThumbs = this.mySwiperThumbs;
      if (swiperTop) {

        swiperTop.controller.control = swiperThumbs;
        swiperThumbs.controller.control = swiperTop;

      }
    });
 },
  created () {

    if (
      this.product &&
      this.product.id_product_attribute &&
      this.product.all_combinations &&
      this.product.all_combinations['minimal']
    ) {

        this.qty = +this.product.all_combinations['minimal'][this.product.id_product_attribute];
        this.maxQty = Number(this.product.all_combinations.max_bundles_per_pallet[this.product.id_product_attribute]);
      } else {

        this.qty = +this.product.minimal_quantity;

    }

  },
  props: ['product'],
  data () {
    return {
      initialized: false,
      swiperOption: {
        dots: false,
        spaceBetween: 10,
        centeredSlides: false,
        slidesPerView: 1,
        initialSlide: 0
      },
      swiperOptionThumbs: {
        initialSlide: 0,
        spaceBetween: 10,
        centeredSlides: true,
        slidesPerView: "auto",
        touchRatio: 0.2,
        slideToClickedSlide: true
      },
      comb_not_found: false,
      qty: 0,
      addProcess: false,
      maxBundleLoad: false,
      maxQty: null,
      dialog: false
    }
  },
  methods: {
    wasPrice(price) {
      var total;
      var p = price;
      if (!p) {
        return;
      }
      var pri = p.replace('$', '');
      var pric = pri.replace(',', '');
      total = +pric + +pric * 10 / 100;
      var t = parseFloat(total).toFixed(2);
      return Number(t).toLocaleString('en-US', { style: 'currency', currency: 'USD' });
    },
    maxBundleQtyToCart() {
      this.maxBundleLoad = true;
      this.getMaxQty();
      this.setProductToCart(this.maxQty);
    },
    addToCart() {
      if (this.qty < this.getMinimalQty()) {
        this.$store.commit('showSnackBar', 'Wire quantity should be at least ' + this.getMinimalQty);
        return false;
      }
      this.addProcess = true;
      var qty = this.qty;
      this.setProductToCart(this.qty);
    },
    setProductToCart(qty) {
      var ip =  this.product.id_product;
      var ipa = this.product.id_product_attribute;

      var form_data = new FormData();
      form_data.append('id_product', ip);
      form_data.append('id_product_attribute', ipa);
      form_data.append('qty', qty);

      axios.post(this.$store.state.api_domain + '?comp=process&action=addToCart', form_data, {withCredentials: true})
      .then((res) => {
        this.addProcess = false;
        this.maxBundleLoad = false;
        if (res.data.status == 'error') {
          this.addToCart();
        }
        if (res.data.status == 'success') {
          this.$store.commit('setCart', res.data.message);
          this.dialog = false;
          this.$store.commit('cartDrawer', true);
          console.log(res.data.cache_reset);
          if (res.data.cache_reset) {
            var cache_key = 'product_' + ip;
            this.$cache.del(cache_key);
          }
        }
      })
      .catch((e) => {
        this.addProcess = false;
        console.log(e);
      });
    },
    getSelected(cc) {
      var iag = cc.id_attribute_group; //Id attribute group
      var iav = cc.value; //Id Attribute value
      var current_combination = this.product.id_product_attribute;
      var dc = this.product.all_combinations.default_combination_values; //All attribute combinations
      if (dc[iag] == cc.value) {
        return ' active';
      }

      return '';
    },
    changeAttribute(cc) {
      var iag = cc.id_attribute_group; //Id attribute group
      var iav = cc.value; //Id Attribute value
      var current_combination = this.product.all_combinations.default_combination_values;
      var ac = this.product.all_combinations.combinations; //All attribute combinations
      this.product.all_combinations.default_combination_values[iag] = cc.value; //Triggered change
      var dc = this.product.all_combinations.default_combination_values;
      this.product.all_combinations.price_impact[cc.value];
      var matches = false;
      for (var comb in ac) {
        for (var d in dc) {
          if (d && d !== 'undefined') {
            if (ac[comb][d] != dc[d]) {
              break;
            } else {
              for (var dd in dc) {
                if (ac[comb][dd] == dc[d]) {
                  matches = true;
                } else {
                  matches = false;
                }
              }
            }
          }
        }
        if (matches) {
            this.comb_not_found = false;
            this.product.id_product_attribute = comb;
            break;
        } else {
          this.comb_not_found = true;
        }
      }
      this.getQty(); //Trigger qty change
      this.getPrice(); //Trigger price change
      this.getMaxQty();
      // this.wasPrice(this.product.regular_price);
    },
    generateAttributeURL (ipa) {
      var route = this.$route;

      var newURL = '/';

      if (this.$route.params.bale) {
        newURL += this.$route.params.bale + '/';
      }

      if (this.$route.params.url) {
        newURL += this.$route.params.url + '/';
      }

      if (this.$route.params.productid) {
        newURL += this.$route.params.productid + '/';
      }

      newURL += ipa;

      return newURL;
    },
    getQty() {
      if (this.product.id_product_attribute) {
        this.qty = this.product.all_combinations['minimal'][this.product.id_product_attribute];
      } else {
        this.qty = this.product.minimal_quantity;
      }
      return this.qty;
    },
    getPrice() {
      var ipa = this.product.id_product_attribute;

      if (this.product.id_product_attribute) {
        this.product.price = this.cNumber(this.product.all_combinations.price_impact[ipa]);
      } else {
        var p = this.product.regular_price;
        this.product.price = this.cNumber(p);
      }

      return this.product.price;
    },
    cNumber: function(val) {
      var p = val.replace(',','');
      return Number(p).toLocaleString('en-US', { style: 'currency', currency: 'USD' })
    },
    getMaxQty() {
      var ipa = this.product.id_product_attribute;
      console.log(this.product);
      if (this.product.id_product_attribute) {
        this.maxQty = Number(this.product.all_combinations.max_bundles_per_pallet[ipa]);
      }
    },
    getMinimalQty() {


      if (
        this.product &&
        this.product.id_product_attribute &&
        this.product.all_combinations &&
        this.product.all_combinations['minimal']
      ) {
        return this.product.all_combinations['minimal'][this.product.id_product_attribute];
      } else {
        return this.product.minimal_quantity;
      }

    },
    changeQty(add) {
      if (add) {
        this.qty = +this.qty + 1;
        if (this.product.product_type == 'Bale') {
          if (this.qty <= 4 && this.product.quantity < this.qty) {
            this.qty = 5;
          }
        }
      } else {
        var qty = this.qty;
        this.qty = +this.qty - 1;
        if (this.product.product_type == 'Bale') {
          if (this.qty <= 4 && this.product.quantity < this.qty) {
            this.qty = this.product.quantity;
          }
        }

        if (this.qty < this.getMinimalQty()) {
          this.qty = qty;
        }

      }
    },
  }
}
</script>
